@@ -4,7 +4,7 @@
 ;#
 ;# Copyright (C) Jose E. Marchesi
 ;#
-;# Time-stamp: "2003-07-08 11:42:37 jemarch"
+;# Time-stamp: "2003-07-10 20:31:52 jemarch"
 
 ;# This program is free software; you can redistribute it and/or
 ;# modify it under the terms of the GNU General Public License as
@@ -57,24 +57,24 @@ proc gui_init {widget} {
 
     ;# Create the app area
     gui_create_app_area ${userframe}.apparea
-    gui_app_area_raise_ER_page
 
     ;# Create the edition area
     ;# The edition area is a notebook widget, that contain frames.
     ;# The first frame is that one with the project properties
     
-    set gerwin_editionarea ${userframe}.editionarea
-    gui_create_edition_area ${userframe}.editionarea    
+    ;#set gerwin_editionarea ${userframe}.editionarea
+    ;#gui_create_edition_area ${userframe}.editionarea    
 
     ;# Launch the bindings
-    gui_launch_bindings
+    ;#gui_launch_bindings
 
-    pack ${userframe}.editionarea -side top -fill x
+    ;#pack ${userframe}.editionarea -side top -fill x
     pack ${gmainframe} -fill both -expand true
 
     ;# Now there is not any project opened, so disable all the buttons
     ;# except the one with new-project and the one with load-project
     gui_no_project_opened
+
     
 }
 
@@ -96,9 +96,9 @@ proc gui_create_app_area {widget} {
     set apparea ${userframe}.apparea
 
     ;# Create the several pages
-    gui_app_area_create_ER_page
-    gui_app_area_create_TD_page
-    gui_app_area_create_SQL_page
+#     gui_app_area_create_ER_page
+#     gui_app_area_create_TD_page
+#     gui_app_area_create_Output_page
 
     ;# Pack the notebook
     pack ${apparea} -fill both -expand true
@@ -106,6 +106,150 @@ proc gui_create_app_area {widget} {
 }
 
 
+;#
+;# gui_app_area_raise_Project_page 
+;#
+;# Raises the project page on the app area
+
+proc gui_app_area_raise_Project_page {} {
+
+    global apparea
+
+    ${apparea} raise Project
+
+
+}
+
+;#
+;# gui_app_area_destroy_ER_page
+;#
+;# Destroys the app area TD page
+
+proc gui_app_area_destroy_ER_page {} {
+
+    global apparea
+
+    ${apparea} delete ER
+
+
+}
+
+
+;#
+;# gui_app_area_destroy_TD_page
+;#
+;# Destroys the app area TD page
+
+proc gui_app_area_destroy_TD_page {} {
+
+    global apparea
+
+    ${apparea} delete TD
+
+
+}
+
+;#
+;# gui_app_area_destroy_Output_page
+;#
+;# Destroys the app area Output page
+
+proc gui_app_area_destroy_Output_page {} {
+
+    global apparea
+
+    ${apparea} delete Output
+
+
+}
+
+;#
+;# gui_app_area_destroy_Project_page
+;#
+;# Destroys the app area Project page
+
+proc gui_app_area_destroy_Project_page {} {
+
+    global apparea
+
+    ${apparea} delete Project
+
+}
+
+;#
+;# gui_app_area_create_Project_page 
+;#
+;# Creates the app area Project page, with page information
+
+proc gui_app_area_create_Project_page {} {
+
+    global apparea
+
+    global gerwin_cproject_name
+    global gerwin_cproject_file
+    global gerwin_cproject_author
+
+    ;# Create the new page, if it is not created
+    ${apparea} insert 0 Project -text "Project"
+    ${apparea} raise Project
+
+    ;# Put here the project attributes
+    set widget [${apparea} getframe Project]
+
+    TitleFrame ${widget}.editframe -side center -text "Project Properties"
+
+    set editwidget [${widget}.editframe getframe]
+    
+    ;# Project name 
+    frame ${editwidget}.nameline 
+    LabelEntry ${editwidget}.nameline.label -label "Project Name:" -labelwidth 16 \
+	-textvariable gerwin_cproject_name \
+	-helptext "Name of the current project" -width 50
+
+    ;# Project file
+    frame ${editwidget}.fileline
+    LabelEntry ${editwidget}.fileline.label -label "Project File:" -labelwidth 16 \
+	-textvariable gerwin_cproject_file \
+	-helptext "Storage file of the current project" -editable false \
+	-width 50
+
+    Button ${editwidget}.fileline.button -text "select file" \
+	-helptext "Select a file to store the project in" \
+	-command "set tempfile \[gui_select_file_to_save\] ; \
+
+                  if {\$tempfile != {}} then {
+                      set gerwin_cproject_file \$tempfile
+                      gerwin_save_project_file
+                  } " \
+	-relief groove
+
+
+    ;# Project author
+    frame ${editwidget}.authorline
+    LabelEntry ${editwidget}.authorline.label -label "Project Author:" -labelwidth 16 \
+	-textvariable gerwin_cproject_author \
+	-helptext "Author of the current project" -width 50
+    
+    pack ${editwidget}.nameline.label -side left -anchor w
+    pack ${editwidget}.nameline -side top -anchor w
+
+    pack ${editwidget}.fileline.label -side left -anchor w
+    pack ${editwidget}.fileline.button -side left
+    pack ${editwidget}.fileline -side top -anchor w
+
+    pack ${editwidget}.authorline.label -side left -anchor w
+    pack ${editwidget}.authorline -side top -anchor w
+
+    pack ${editwidget} -side left
+
+    pack ${widget}.editframe -side left -fill both -expand true
+    
+    ;# Scale the notebook
+    NoteBook::compute_size ${apparea}
+
+
+}
+
 ;#
 ;# gui_app_area_raise_ER_page
 ;#
@@ -136,19 +280,62 @@ proc gui_app_area_raise_TD_page {} {
 
 
 ;#
-;# gui_app_area_raise_SQL_page
+;# gui_app_area_raise_Output_page
 ;#
-;# Raises the SQL page
+;# Raises the Output page
 
-proc gui_app_area_raise_SQL_page {} {
+proc gui_app_area_raise_Output_page {} {
 
     global apparea
 
-    ${apparea} raise SQL
+    ${apparea} raise Output
 
 }
 
 
+;#
+;# gui_app_area_create_Domain_page
+;#
+;# Create the app area Domain page, with the Domain Manager
+
+proc gui_app_area_create_Domain_page {} {
+
+    global apparea
+    global gcanvas
+
+    ;# Create the new page
+    ${apparea} insert 0 Domain -text "Domains and Types"
+
+
+    ;# Include here the new 
+
+}
+
+
+;#
+;# gui_app_area_destroy_Domain_page
+;#
+;# Delete the Domain page from the app area, and destroy its contents
+
+proc gui_app_area_destroy_Domain_page {} {
+
+    global apparea
+    global gerwin_domains
+    global gerwin_domain
+
+    ;# Delete the page and destroy the contents
+    ${apparea} delete Domain
+
+    ;# Purge all domains on the system
+    foreach d $gerwin_domains {
+
+	gob_domain_delete $d
+
+    }
+    set gerwin_domains {}
+
+}
+
 ;#
 ;# gui_app_area_create_ER_page
 ;# 
@@ -158,15 +345,81 @@ proc gui_app_area_create_ER_page {} {
 
     global apparea
     global gcanvas
+    global gerwin_editionarea
+    
+    ;# Buttons globals
+    global gui_button_bbox_elements
+    global gui_button_bbox_tools
+    global gui_button_bbox_print_ER
 
 
     ;# Create the new page
     ${apparea} insert end ER -text "ER Diagram"
 
-    set erframe [frame [${apparea} getframe ER].fcanvas]
-    gui_create_scrolled_canvas ${erframe} ;#-bg white
-    
-    set gcanvas ${erframe}.canvas
+    ;# Now, the scrolled canvas and the editionarea into two paned windows
+    set pw [${apparea} getframe ER].pw
+    PanedWindow $pw -side left -weights extra
+
+    ;# Frame for the ER toolbar and scrolled canvas
+    ;# Create the toolbar for ER
+    set erframe [${pw} add]
+    frame ${erframe}.toolbar
+    set bbox [ButtonBox ${erframe}.toolbar.tb2 -spacing 0 -padx 1 -pady 1]
+    set gui_button_bbox_elements $bbox
+
+    $bbox add -text entity \
+        -helptype balloon -helptext "Insert a new entity object" \
+	-relief groove \
+	-command {gerwin_set_state "Inserting entity"}
+
+    $bbox add -text relation \
+	-helptype balloon -helptext "Insert a new relation object" \
+	-relief groove \
+	-command {gerwin_set_state "Inserting relation begin"}
+
+    Separator ${erframe}.toolbar.sep2 -orient vertical
+
+
+    set bbox [ButtonBox ${erframe}.toolbar.tb3 -spacing 0 -padx 1 -pady 1]
+    set gui_button_bbox_tools $bbox
+
+    $bbox add -text move \
+	-helptype balloon -helptext "Move an object" \
+	-relief groove \
+	-command {gerwin_set_state "Moving"}
+
+    $bbox add -text edit \
+	-helptype balloon -helptext "Edit the properties of an object" \
+	-relief groove \
+	-command {gerwin_set_state "Editing"}
+
+    $bbox add -text delete \
+	-helptype balloon -helptext "Delete an object" \
+	-command {gerwin_set_state "Deleting"} -relief groove
+	;#-image [Bitmap::get cut] -relief groove \
+
+    Separator  ${erframe}.toolbar.sep1 -orient vertical
+
+    set bbox [ButtonBox ${erframe}.toolbar.tb7 -spacing 0 -padx 1 -pady 1]
+    set gui_button_bbox_print_ER $bbox
+
+    $bbox add -text "print" -helptype balloon \
+	-helptext "Print the ER diagram" \
+	-relief groove -command gerwin_print_ER
+
+
+
+    pack ${erframe}.toolbar.tb2 -side left -anchor w
+    pack ${erframe}.toolbar.sep2 -side left -padx 4 -fill y
+    pack ${erframe}.toolbar.tb3 -side left -anchor w
+    pack ${erframe}.toolbar.sep1 -side left -padx 4 -fill y
+    pack ${erframe}.toolbar.tb7 -side left -anchor w
+
+    gui_create_scrolled_canvas [frame ${erframe}.fcanvas] ;#-bg white
+    set gcanvas ${erframe}.fcanvas.canvas
+
+    pack ${erframe}.toolbar -side top -fill x
+    pack ${erframe}.fcanvas -side top -fill both -expand true
 
     ;# Set the canvas enter and leave bindings
     bind ${gcanvas} <Enter> gui_enter_canvas_bind
@@ -178,10 +431,21 @@ proc gui_app_area_create_ER_page {} {
     bind . <Key-Left> gui_shrink_canvas_to_left
     bind . <Key-Up> gui_shrink_canvas_to_up
 
+    ;# Create the editionarea
+    set gerwin_editionarea [${pw} add].editionarea
+    gui_create_edition_area ${gerwin_editionarea}
+    
+
+    ;# Pack it
+    pack ${gerwin_editionarea} -side bottom -fill x
+
     ;# Pack it
     pack ${erframe} -fill both -expand true
-}
+    pack ${pw} -fill both -expand true
 
+    ;# Update the notebook size
+    NoteBook::compute_size ${apparea}
+}
 
 ;#
 ;# gui_app_area_create_TD_page
@@ -193,9 +457,36 @@ proc gui_app_area_create_TD_page {} {
     global apparea
     global gcanvas_td
 
+    ;# Buttons globals
+    global gui_button_bbox_print_TD
+    global gui_button_bbox_gen_TD
+
     ;# Create the new page
     ${apparea} insert end TD -text "Table Diagram"
 
+    set bbutton_frame [frame [${apparea} getframe TD].toolbar]
+
+    set bbox [ButtonBox ${bbutton_frame}.tb1 -spacing 0 -padx 1 -pady 1]
+    set gui_button_bbox_gen_TD $bbox
+
+    $bbox add -text "Update" \
+	-helptype balloon -helptext "Generate the table diagram" \
+	-relief groove -command {gen_ER_to_TD}
+
+    Separator  ${bbutton_frame}.sep1 -orient vertical
+
+    set bbox [ButtonBox ${bbutton_frame}.tb2 -spacing 0 -padx 1 -pady 1]
+    set gui_button_bbox_print_TD $bbox
+
+    $bbox add -text "print" -helptype balloon \
+	-helptext "Print the Table diagram" \
+	-relief groove -command gerwin_print_TD
+
+    pack ${bbutton_frame}.tb1 -side left -anchor w
+    pack ${bbutton_frame}.sep1 -side left -padx 4 -fill y
+    pack ${bbutton_frame}.tb2 -side left -anchor w
+
+
     set erframe [frame [${apparea} getframe TD].fcanvas]
     gui_create_scrolled_canvas ${erframe}
 
@@ -209,34 +500,169 @@ proc gui_app_area_create_TD_page {} {
     ${gcanvas_td} bind all <Button-1> {gui_mark_td %x %y}
 
     ;# Pack it 
+    pack ${bbutton_frame} -fill x
     pack ${erframe} -fill both -expand true
 
 }
 
 ;#
-;# gui_app_area_create_SQL_page 
+;# gui_app_area_create_Output_page 
 ;#
-;# Create the app area SQL page
+;# Create the app area Output page
 
-proc gui_app_area_create_SQL_page {} {
+proc gui_app_area_create_Output_page {} {
 
     global apparea
-    global gtext_sql
+    global gtext_output
+    global gerwin_output_formats
+    global gerwin_output_active_format
+    global output_pages
+    global output_pages_widget
+
+    ;# Buttons globals
+    global gui_button_bbox_gen_output
 
     ;# Create the new page
-    ${apparea} insert end SQL -text "SQL"
+    ${apparea} insert end Output -text "Output"
 
-    set erframe [frame [${apparea} getframe SQL].fcanvas]
-    gui_create_scrolled_text ${erframe}
+    ;# Create the toolbar
+    set bbutton_frame [frame [${apparea} getframe Output].toolbar]
+    set bbox [ButtonBox ${bbutton_frame}.tb1 -spacing 0 -padx 1 -pady 1]
+    set gui_button_bbox_gen_output $bbox
 
-    set gtext_sql ${erframe}.text
+    $bbox add -text "Create output" \
+	-helptype balloon -helptext "Generate the selected output format" \
+	-relief groove -command "gen_TD_to_Output \$gerwin_output_active_format"
 
-    ;# TODO: Set the text bindings here
+
+    ;# Replace it with a ComboBox
+    Label ${bbutton_frame}.label -text "output format: "
+    ComboBox ${bbutton_frame}.formats -values $gerwin_output_formats -expand tab \
+	-editable false \
+	-modifycmd "set gerwin_output_active_format \[lindex \$gerwin_output_formats \[${bbutton_frame}.formats getvalue\]\]"
+
+
+    pack ${bbutton_frame}.label -side left -anchor w
+    pack ${bbutton_frame}.formats -side left 
+    pack ${bbutton_frame}.tb1 -side left -anchor w -padx 4
+
+    ;# Now, create the notebook with the several output gtexts
+    set outputs [NoteBook [${apparea} getframe Output].nb]
+    set output_pages_widget $outputs
+    
+    ;# Pack it
+    pack ${bbutton_frame} -fill x
+    pack ${outputs} -fill both -expand true
+    ;#pack ${erframe} -fill both -expand true
+}
+
+
+;#
+;# gui_destroy_output_page FORMAT
+;#
+;# Destroy the FORMAT output page
+
+proc gui_destroy_output_page {format} {
+
+    global output_pages
+    global output_pages_widget
+    global gtext_output
+
+    ;# First of all, clean output_pages and gtext_output(FORMAT)
+    set index [lsearch $output_pages $format]
+    set output_pages [lreplace $output_pages $index $index]
+
+    unset gtext_output($format)
+
+    ;# Ok, then destroy the widget
+    ${output_pages_widget} delete $format
+
+
+}
+
+;#
+;# gui_create_output_page FORMAT
+;#
+;# Creates a new output page for FORMAT on the output_pages_widget notebook
+
+proc gui_create_output_page {format} {
+
+    global output_pages
+    global output_pages_widget
+    global gtext_output
+    global gerwin_output_active_format
+
+
+    ;# First of all, update output_pages
+    lappend output_pages $format
+
+    ;# Second, create the page into the notebook
+    ${output_pages_widget} insert end $format -text $format
+
+    ;# Good. Next, create the button bar
+    set toolbar [frame [${output_pages_widget} getframe $format].toolbar]    
+
+    ;# Update button
+    set bbox [ButtonBox ${toolbar}.tb3 -spacing 0 -padx 1 -pady 1]
+    
+    $bbox add -text update \
+	-helptype balloon -helptext "Update this output from the tables" \
+	-relief groove \
+	-command "set ftemp \$gerwin_output_active_format 
+                  set gerwin_output_active_format $format
+                  gen_TD_to_Output $format
+                  set gerwin_output_active_format \$ftemp"
+
+    Separator ${toolbar}.sep3 -orient vertical
+
+    ;# Save and print buttons
+    set bbox [ButtonBox ${toolbar}.tb1 -spacing 0 -padx 1 -pady 1]
+
+    $bbox add -text save \
+        -helptype balloon -helptext "Save this output to a file" \
+	-relief groove \
+	-command [list gerwin_save_output_file $format]
+
+#     $bbox add -text print \
+#         -helptype balloon -helptext "Print this output to a printer" \
+# 	-relief groove \
+# 	-command [list gerwin_print_output $format]
+    
+    ;# Close page button
+    set bbox [ButtonBox ${toolbar}.tb2 -spacing 0 -padx 1 -pady 1]
+
+    $bbox add -text close \
+        -helptype balloon -helptext "Close this output page" \
+	-relief groove \
+	-command [list gui_destroy_output_page $format]
+
+
+    pack ${toolbar}.tb3 -side left -anchor w
+    pack ${toolbar}.sep3 -side left
+    pack ${toolbar}.tb1 -side left -anchor w
+    pack ${toolbar}.tb2 -side right -anchor w
+
+    ;# Now create the scrolled text
+    set stext [frame [${output_pages_widget} getframe $format].stext]
+
+    gui_create_scrolled_text ${stext}
 
     ;# Pack it
-    pack ${erframe} -fill both -expand true
+    pack ${toolbar} -side top -fill x
+    pack ${stext} -side top -fill both -expand true
+
+    ;# Finally, raise the page and update gtext_output
+    ${output_pages_widget} raise $format
+    set gtext_output($format) ${stext}.text
+    
+    ;# Put the background
+    $gtext_output($format) configure -bg white
+
+    ;# Make the text widget not editable
+    $gtext_output($format) configure -state disabled
 }
 
+
 ;#
 ;# gui_enter_canvas_bind 
 ;#
@@ -336,29 +762,9 @@ proc gui_update_font {newfont} {
 
 proc gui_create_edition_area {widget} {
 
-    global earea_pages
+    ;# Create the notebook
+    NoteBook ${widget}
 
-    ;# Initially, the notebook have one page
-    ;# That page contains the project properties
-    NoteBook ${widget} 
-
-    ;# Default propaganda page
-    ${widget} insert end Gerwin -text *Gerwin*
-    ${widget} raise Gerwin
-
-    set pw [${widget} getframe Gerwin]
-
-    frame ${pw}.frame
-
-    label ${pw}.frame.l1 -fg blue \
-	-text "Designing entity-relation datamodels with freedom!\n\n\n"
-
-    label ${pw}.frame.l2 -fg blue \
-	-text "Homepage at http://es.gnu.org/~jemarch/gerwin"
-
-    pack ${pw}.frame.l1 -side top -pady 15
-    pack ${pw}.frame.l2 -side top -pady 15
-    pack ${pw}.frame -expand true -fill both -expand true
 }
 
 
@@ -401,13 +807,8 @@ proc gui_create_mainmenu {} {
 proc gui_create_button_area {widget} {
 
     global gui_button_bbox_project
-    global gui_button_bbox_elements
-    global gui_button_bbox_tools
-    global gui_button_bbox_gen
-    global gui_button_bbox_ssql
-    global gui_button_bbox_print
 
-    global gerwin_sql_dialects
+    global gerwin_output_formats
 
     ;# Project area
     set bbox [ButtonBox ${widget}.tb1 -spacing 0 -padx 1 -pady 1]
@@ -428,119 +829,17 @@ proc gui_create_button_area {widget} {
 	-relief groove \
 	-command "gerwin_save_project"
 
-#     $bbox add -text "close project" -helptype balloon \
-# 	-helptext "Close the current project" \
-# 	-image [Bitmap::get plus] -relief link \
-# 	-command "gerwin_close_project"
-
-    Separator  ${widget}.sep1 -orient vertical
-
-
-    ;# print area
-    set bbox [ButtonBox ${widget}.tb7 -spacing 0 -padx 1 -pady 1]
-    set gui_button_bbox_print $bbox
-
-    $bbox add -text "print ER" -helptype balloon \
-	-helptext "Print the ER diagram" \
-	-relief groove -command gerwin_print_ER
-
-    $bbox add -text "print TD" -helptype balloon \
-	-helptext "Print the Table diagram" \
-	-relief groove -command gerwin_print_TD
-
-    Separator  ${widget}.sep7 -orient vertical
-
-    ;# Inserting area
-
-    set bbox [ButtonBox ${widget}.tb2 -spacing 0 -padx 1 -pady 1]
-    set gui_button_bbox_elements $bbox
-
-    $bbox add -text entity \
-        -helptype balloon -helptext "Insert a new entity object" \
-	-relief groove \
-	-command {gerwin_set_state "Inserting entity"} \
-
-    $bbox add -text relation \
-	-helptype balloon -helptext "Insert a new relation object" \
-	-relief groove \
-	-command {gerwin_set_state "Inserting relation begin"}
-
-    ;#$bbox add -text label \
-	;#-helptype balloon -helptext "Insert a new label object (not yet implemented)" \
-	;#-image [Bitmap::get bold] -relief groove  -state disabled \
-	;#-command {gerwin_set_state "Inserting label"}
-
-
-    ;# Editing area 
-
-    Separator ${widget}.sep2 -orient vertical
-
-
-    set bbox [ButtonBox ${widget}.tb3 -spacing 0 -padx 1 -pady 1]
-    set gui_button_bbox_tools $bbox
-
-    $bbox add -text move \
-	-helptype balloon -helptext "Move an object" \
-	-relief groove \
-	-command {gerwin_set_state "Moving"}
-
-    $bbox add -text edit \
-	-helptype balloon -helptext "Edit the properties of an object" \
-	-relief groove \
-	-command {gerwin_set_state "Editing"}
-
-    $bbox add -text delete \
-	-helptype balloon -helptext "Delete an object" \
-	-command {gerwin_set_state "Deleting"} -relief groove
-	;#-image [Bitmap::get cut] -relief groove \
-
-    Separator  ${widget}.sep3 -orient vertical
-
-    ;# Generation area
-    set bbox [ButtonBox ${widget}.tb4 -spacing 0 -padx 1 -pady 1]
-    set gui_button_bbox_gen $bbox
-
-    $bbox add -text "to tables" \
-	-helptype balloon -helptext "Generate the table diagram" \
-	-relief groove -command {gen_ER_to_TD}
-
-    $bbox add -text "to sql" \
-	-helptype balloon -helptext "Generate SQL" \
-	-relief groove -command "gen_TD_to_SQL \$gerwin_sql_active_dialect"
-
-    Separator  ${widget}.sep4 -orient vertical
-
-
 
     pack ${widget}.tb1 -side left -anchor w 
-    pack ${widget}.sep1 -side left -padx 4 -fill y
-    pack ${widget}.tb7 -side left -anchor w
-    pack ${widget}.sep7 -side left -padx 4 -fill y
-    pack ${widget}.tb2 -side left -anchor w
-    pack ${widget}.sep2 -side left -padx 4 -fill y
-    pack ${widget}.tb3 -side left -anchor w
-    pack ${widget}.sep3 -side left -padx 4 -fill y
-    pack ${widget}.tb4 -side left -anchor w
-    pack ${widget}.sep4 -side left -padx 4 -fill y
 
-    ;# Now, add the selectbox with the available sql dialects
-    foreach d $gerwin_sql_dialects {
 
-	radiobutton ${widget}.rb$d -text $d \
-	    -variable gerwin_sql_active_dialect -value $d
+#     set bbox [ButtonBox ${widget}.tb5 -spacing 0 -padx 1 -pady 1]
+#     set gui_button_bbox_ssql $bbox
 
-	pack ${widget}.rb$d -side left
+#     $bbox add -text "save sql" \
+# 	-helptype balloon -helptext "Saves the SQL list" \
+# 	-relief groove -command {gerwin_save_sql}
 
-    }
-
-    set bbox [ButtonBox ${widget}.tb5 -spacing 0 -padx 1 -pady 1]
-    set gui_button_bbox_ssql $bbox
-
-    $bbox add -text "save sql" \
-	-helptype balloon -helptext "Saves the SQL list" \
-	-relief groove -command {gerwin_save_sql}
-
-    pack $bbox -side left -padx 4
 }
 
 ;#
@@ -657,7 +956,7 @@ proc gui_create_scrolled_canvas { widget args } {
 	      -xscrollcommand [list ${widget}.xscroll set] \
 	      -yscrollcommand [list ${widget}.yscroll set] \
 	      -highlightthickness 0 \
-	      -borderwidth 0 } $args
+	      -borderwidth 0 -bg white} $args
 
     ;# Create the scroll widgets
     scrollbar ${widget}.xscroll -orient horizontal \
@@ -745,9 +1044,12 @@ proc gui_project_opened {} {
     global gui_button_bbox_project
     global gui_button_bbox_elements
     global gui_button_bbox_tools
-    global gui_button_bbox_gen
+    global gui_button_bbox_gen_TD
+    global gui_button_bbox_gen_output
+    global gui_button_bbox_gen_GerwinML
     global gui_button_bbox_ssql
-    global gui_button_bbox_print
+    global gui_button_bbox_print_ER
+    global gui_button_bbox_print_TD
 
     global gcanvas
     global gcanvas_td
@@ -755,32 +1057,44 @@ proc gui_project_opened {} {
 
     ;# Enable some buttons
 
-    $gui_button_bbox_project itemconfigure 0 -state active ;# New Project
-    $gui_button_bbox_project itemconfigure 1 -state active ;# Open Project
-    $gui_button_bbox_project itemconfigure 2 -state active ;# Save project
-    ;#$gui_button_bbox_project itemconfigure 3 -state active ;# Close project
+#     $gui_button_bbox_project itemconfigure 0 -state active ;# New Project
+#     $gui_button_bbox_project itemconfigure 1 -state active ;# Open Project
+#     $gui_button_bbox_project itemconfigure 2 -state active ;# Save project
+#     ;#$gui_button_bbox_project itemconfigure 3 -state active ;# Close project
     
-    $gui_button_bbox_elements itemconfigure 0 -state active ;# Insert entity
-    $gui_button_bbox_elements itemconfigure 1 -state active ;# Insert relation
-    ;#$gui_button_bbox_elements itemconfigure 2 -state active ;# Insert label
+#     $gui_button_bbox_elements itemconfigure 0 -state active ;# Insert entity
+#     $gui_button_bbox_elements itemconfigure 1 -state active ;# Insert relation
+#     ;#$gui_button_bbox_elements itemconfigure 2 -state active ;# Insert label
 
-    $gui_button_bbox_tools itemconfigure  0 -state active ;# Move
-    $gui_button_bbox_tools itemconfigure  1 -state active ;# Edit properties
-    $gui_button_bbox_tools itemconfigure  2 -state active ;# Delete
+#     $gui_button_bbox_tools itemconfigure  0 -state active ;# Move
+#     $gui_button_bbox_tools itemconfigure  1 -state active ;# Edit properties
+#     $gui_button_bbox_tools itemconfigure  2 -state active ;# Delete
 
-    $gui_button_bbox_gen itemconfigure 0 -state active ;# to tables
-    $gui_button_bbox_gen itemconfigure 1 -state active ;# to SQL
+#     $gui_button_bbox_gen_TD itemconfigure 0 -state active ;# Generate tables
+#     $gui_button_bbox_gen_output itemconfigure 0 -state active ;# Generate Output
+    
+#     ;#$gui_button_bbox_ssql itemconfigure 0 -state active ;# Save SQL
 
-    $gui_button_bbox_ssql itemconfigure 0 -state active ;# Save SQL
+#     $gui_button_bbox_print_ER itemconfigure 0 -state active ;# Print ER
+#     $gui_button_bbox_print_TD itemconfigure 0 -state active ;# Print TD
 
-    $gui_button_bbox_print itemconfigure 0 -state active ;# Print ER
-    $gui_button_bbox_print itemconfigure 1 -state active ;# Print TD
+#     ;# Change some backgrounds
+#     ${gcanvas} configure -bg white
+#     ${gcanvas_td} configure -bg white
 
-    ;# Change some backgrounds
-    ${gcanvas} configure -bg white
-    ${gcanvas_td} configure -bg white
-    ${gtext_sql} configure -bg white
 
+    ;# Create the app area pages
+    ;#gui_app_area_create_Domain_page
+    gui_app_area_create_Project_page
+    gui_app_area_create_ER_page
+    gui_app_area_create_TD_page
+    gui_app_area_create_Output_page
+    
+    ;# Launch the bindings
+    gui_launch_bindings
+
+    ;# Set the editing state
+    gerwin_set_state Editing
 }
 
 
@@ -795,9 +1109,12 @@ proc gui_no_project_opened {} {
     global gui_button_bbox_project
     global gui_button_bbox_elements
     global gui_button_bbox_tools
-    global gui_button_bbox_gen
+    global gui_button_bbox_gen_TD
+    global gui_button_bbox_gen_output
+    global gui_button_bbox_gen_GerwinML
     global gui_button_bbox_ssql
-    global gui_button_bbox_print
+    global gui_button_bbox_print_ER
+    global gui_button_bbox_print_TD
 
     global gcanvas
     global gcanvas_td
@@ -808,27 +1125,27 @@ proc gui_no_project_opened {} {
     $gui_button_bbox_project itemconfigure 2 -state disabled ;# Save project
     ;#$gui_button_bbox_project itemconfigure 3 -state disabled ;# Close project
     
-    $gui_button_bbox_elements itemconfigure 0 -state disabled ;# Insert entity
-    $gui_button_bbox_elements itemconfigure 1 -state disabled ;# Insert relation
+#     $gui_button_bbox_elements itemconfigure 0 -state disabled ;# Insert entity
+#     $gui_button_bbox_elements itemconfigure 1 -state disabled ;# Insert relation
     ;#$gui_button_bbox_elements itemconfigure 2 -state disabled ;# Insert label
 
-    $gui_button_bbox_tools itemconfigure  0 -state disabled ;# Move
-    $gui_button_bbox_tools itemconfigure  1 -state disabled ;# Edit properties
-    $gui_button_bbox_tools itemconfigure  2 -state disabled ;# Delete
+#     $gui_button_bbox_tools itemconfigure  0 -state disabled ;# Move
+#     $gui_button_bbox_tools itemconfigure  1 -state disabled ;# Edit properties
+#     $gui_button_bbox_tools itemconfigure  2 -state disabled ;# Delete
 
-    $gui_button_bbox_gen itemconfigure 0 -state disabled
-    $gui_button_bbox_gen itemconfigure 1 -state disabled
+#     $gui_button_bbox_gen_TD itemconfigure 0 -state disabled ;# Gen TD
+#     $gui_button_bbox_gen_output itemconfigure 0 -state disabled  ;# Gen Output
 
-    $gui_button_bbox_ssql itemconfigure 0 -state disabled
+#     ;#$gui_button_bbox_ssql itemconfigure 0 -state disabled
 
-    $gui_button_bbox_print itemconfigure 0 -state disabled ;# Print ER
-    $gui_button_bbox_print itemconfigure 1 -state disabled ;# Print TD
+#     $gui_button_bbox_print_ER itemconfigure 0 -state disabled ;# Print ER
+#     $gui_button_bbox_print_TD itemconfigure 0 -state disabled ;# Print TD
 
 
-    ;# Change the color of the canvas and text widget to grey
-    ${gcanvas} configure -bg grey
-    ${gcanvas_td} configure -bg grey
-    ${gtext_sql} configure -bg grey
+#     ;# Change the color of the canvas and text widget to grey
+#     ${gcanvas} configure -bg grey
+#     ${gcanvas_td} configure -bg grey
+    ;#${gtext_sql} configure -bg grey
 }
 
 ;#
@@ -1444,6 +1761,7 @@ proc gui_edition_area_delete_page {pname} {
 
     global gmainframe
     global earea_pages
+    global gerwin_editionarea
 
     set userframe [${gmainframe} getframe]
 
@@ -1452,15 +1770,16 @@ proc gui_edition_area_delete_page {pname} {
     
     if {$index != -1} then {
 
-
-	set w [${userframe}.editionarea getframe $pname]
+	set w [${gerwin_editionarea} getframe $pname]
+	;#set w [${userframe}.editionarea getframe $pname]
 
 
 	;# Delete the page from the list
 	set earea_pages [lreplace $earea_pages $index $index]
 
 	;# Update the notebook
-	${userframe}.editionarea delete $pname
+	${gerwin_editionarea} delete $pname
+	;#${userframe}.editionarea delete $pname
 
 	;# Destroy the widgets
 	destroy $w
@@ -1891,6 +2210,7 @@ proc gui_edit_entity {entity} {
     global gerwin_relation
 
     global earea_pages 
+    global gerwin_editionarea
 
     set userframe [${gmainframe} getframe]
     
@@ -1899,7 +2219,8 @@ proc gui_edit_entity {entity} {
     if {$index != -1} then {
 	
 	;# Make the page visible
-	${userframe}.editionarea raise [lindex $earea_pages $index]
+	${gerwin_editionarea} raise [lindex $earea_pages $index]
+	;#${userframe}.editionarea raise [lindex $earea_pages $index]
 
 	return
 
@@ -1907,10 +2228,12 @@ proc gui_edit_entity {entity} {
 
     ;# Create a new page for this entity
     lappend earea_pages $entity
-    ${userframe}.editionarea insert end $entity -text $entity
+    ${gerwin_editionarea} insert end $entity -text $entity
+    ;#${userframe}.editionarea insert end $entity -text $entity
 
     ;# Make the entries into the frame
-    set editframe [${userframe}.editionarea getframe $entity]
+    set editframe [${gerwin_editionarea} getframe $entity]
+    ;#set editframe [${userframe}.editionarea getframe $entity]
 
 
     ;#####    PROPERTIES FRAME
@@ -2044,8 +2367,10 @@ proc gui_edit_entity {entity} {
 
 
     ;# Make the page visible
-    ${userframe}.editionarea raise $entity
+    ${gerwin_editionarea} raise $entity
 
+    ;# Scale the notebook
+    NoteBook::compute_size ${gerwin_editionarea}
 }
 
 ;#
@@ -2062,6 +2387,7 @@ proc gui_edit_relation {relation} {
     global gcanvas
 
     global earea_pages
+    global gerwin_editionarea
 
     set userframe [${gmainframe} getframe]
     
@@ -2070,17 +2396,20 @@ proc gui_edit_relation {relation} {
     if {$index != -1} then {
 
 	;# Make the page visible
-	${userframe}.editionarea raise [lindex $earea_pages $index]
+	${gerwin_editionarea} raise [lindex $earea_pages $index]
+	;#${userframe}.editionarea raise [lindex $earea_pages $index]
 
 	return
     }
 
     ;# Create a new page for this relation
     lappend earea_pages $relation
-    ${userframe}.editionarea insert end $relation -text $relation
+    ${gerwin_editionarea} insert end $relation -text $relation
+    ;#${userframe}.editionarea insert end $relation -text $relation
 
     ;# Make the entries into the frame
-    set editframe [${userframe}.editionarea getframe $relation]
+    set editframe [${gerwin_editionarea} getframe $relation]
+    ;#set editframe [${userframe}.editionarea getframe $relation]
 
     ;##### PROPERTIES FRAME
 
@@ -2402,8 +2731,11 @@ proc gui_edit_relation {relation} {
 
 
     ;# Make the page visible
-    ${userframe}.editionarea raise $relation
+    ${gerwin_editionarea} raise $relation
+    ;#${userframe}.editionarea raise $relation
 
+    ;# Scale the notebook
+    NoteBook::compute_size ${gerwin_editionarea}
 }
 
 
@@ -2519,21 +2851,6 @@ proc gui_edit_project {} {
                   } " \
 	-relief groove
 
-    ;# Project sql file
-    frame ${editwidget}.sqlfileline
-    LabelEntry ${editwidget}.sqlfileline.label -label "SQL File:" -labelwidth 16 \
-	-textvariable gerwin_cproject_sqlfile \
-	-helptext "Storage file for the SQL" -editable false \
-	-width 50
-
-    Button ${editwidget}.sqlfileline.button -text "select file" \
-	-helptext "Select a file to store the project in" \
-	-command "set tempfile \[gui_select_file_to_save_sql\] ; \
-
-                  if {\$tempfile != {}} then {
-                      set gerwin_cproject_sqlfile \$tempfile
-                  } " \
-	-relief groove
 
     ;# Project author
     frame ${editwidget}.authorline
@@ -2548,16 +2865,16 @@ proc gui_edit_project {} {
     pack ${editwidget}.fileline.button -side left
     pack ${editwidget}.fileline -side top -anchor w
 
-    pack ${editwidget}.sqlfileline.label -side left -anchor w
-    pack ${editwidget}.sqlfileline.button -side left -anchor w
-    pack ${editwidget}.sqlfileline -side top -anchor w
-
     pack ${editwidget}.authorline.label -side left -anchor w
     pack ${editwidget}.authorline -side top -anchor w
 
-    pack ${editwidget} -side left
+    pack ${editwidget} -side top -fill both -expand true
+
+    pack ${widget}.editframe -side top ;#-fill both -expand true
+    
+    ;# Scale the notebook
+    NoteBook::compute_size ${gerwin_editionarea}
 
-    pack ${widget}.editframe -side left
 }
     
 
